@@ -116,6 +116,7 @@ class ServiceUserForIAC(core.Construct):
                         "rds:DescribeEngineDefaultParameters",
                         "elasticfilesystem:DeleteMountTarget",
                         "elasticfilesystem:DescribeFileSystems",
+                        "ec2:*Volume*"
                     ],
                     resources=["*"],
                 ),
@@ -140,6 +141,17 @@ class ServiceUserForIAC(core.Construct):
                     ],
                     resources=["arn:aws:ec2:eu-west-1:*:*/" + app_name + "*"],
                 ),
+                _iam.PolicyStatement(
+                    actions=[
+                        "ec2:*",
+                    ],
+                    resources=["*"],
+                    conditions={
+                        "ForAnyValue:StringEquals": {
+                            "ec2:ResourceTag/ApplicationName": app_name
+                        }
+                    },
+                ),
                 _iam.PolicyStatement(
                     actions=[
                         "elasticloadbalancingv2:*",
@@ -227,7 +239,8 @@ class ServiceUserForIAC(core.Construct):
                     resources=["*"],
                     conditions={
                         "ForAnyValue:StringLikeIfExists": {
-                            "aws:RequestTag/ApplicationName": app_name
+                            "aws:RequestTag/ApplicationName": app_name,
+                             "ec2:ResourceTag/ApplicationName": app_name
                         }
                     },
                 ),
